[Libreoffice-commits] core.git: sd/source

Caolán McNamara caolanm at redhat.com
Wed Sep 17 07:00:37 PDT 2014


 sd/source/ui/view/DocumentRenderer.cxx |   28 +++++++++++++++-------------
 1 file changed, 15 insertions(+), 13 deletions(-)

New commits:
commit cca120ad92ecab741ca9683f3cf76d9e4fc81729
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Wed Sep 17 14:32:03 2014 +0100

    Resolves: fdo#80911 don't swap notes page width/height
    
    Change-Id: I9826f69d03de85ea8d2b2c025121599877798852

diff --git a/sd/source/ui/view/DocumentRenderer.cxx b/sd/source/ui/view/DocumentRenderer.cxx
index c370a69..a5ffa6a 100644
--- a/sd/source/ui/view/DocumentRenderer.cxx
+++ b/sd/source/ui/view/DocumentRenderer.cxx
@@ -1361,6 +1361,7 @@ private:
     {
         SdDrawDocument* pDocument = mrBase.GetMainViewShell()->GetDoc();
         rInfo.meOrientation = ORIENTATION_PORTRAIT;
+        bool bDoDodgyHeightWidthFit = !mpOptions->IsDraw() && !mpOptions->IsNotes();
 
         if( ! mpOptions->IsBooklet())
         {
@@ -1369,9 +1370,9 @@ private:
         else if (rInfo.maPageSize.Width() < rInfo.maPageSize.Height())
             rInfo.meOrientation = ORIENTATION_LANDSCAPE;
 
         // Draw should abide by specified paper size
         Size aPaperSize;
-        if (mpOptions->IsDraw())
+        if (!bDoDodgyHeightWidthFit)
         {
             aPaperSize.setWidth(rInfo.maPageSize.Width());
             aPaperSize.setHeight(rInfo.maPageSize.Height());
@@ -1382,18 +1383,19 @@ private:
             aPaperSize.setHeight(rInfo.mpPrinter->GetPaperSize().Height());
         }
 
-        if( (rInfo.meOrientation == ORIENTATION_LANDSCAPE &&
-              (aPaperSize.Width() < aPaperSize.Height()))
-           ||
-            (rInfo.meOrientation == ORIENTATION_PORTRAIT &&
-              (aPaperSize.Width() > aPaperSize.Height()))
-          )
-        {
-            maPrintSize = awt::Size(aPaperSize.Height(), aPaperSize.Width());
-        }
-        else
+        maPrintSize = awt::Size(aPaperSize.Width(), aPaperSize.Height());
+
+        if (bDoDodgyHeightWidthFit)
         {
-            maPrintSize = awt::Size(aPaperSize.Width(), aPaperSize.Height());
+            if( (rInfo.meOrientation == ORIENTATION_LANDSCAPE &&
+                  (aPaperSize.Width() < aPaperSize.Height()))
+               ||
+                (rInfo.meOrientation == ORIENTATION_PORTRAIT &&
+                  (aPaperSize.Width() > aPaperSize.Height()))
+              )
+            {
+                maPrintSize = awt::Size(aPaperSize.Height(), aPaperSize.Width());
+            }
         }
 
         return true;
@@ -1369,9 +1370,9 @@ private:
             rInfo.meOrientation = ORIENTATION_LANDSCAPE;
 
-        // Draw should abide by specified paper size
+        // Draw and Notes should abide by their specified paper size
         Size aPaperSize;


More information about the Libreoffice-commits mailing list